@@ -866,7 +866,7 @@ fr_application_new (void)
 {
         return g_object_new (fr_application_get_type (),
                              "application-id", "org.gnome.FileRoller",
-                             "flags", G_APPLICATION_FLAGS_NONE,
+                             "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
                              NULL);
 }
 
